@@ -25,6 +25,7 @@
 #define __APPLIER_H
 
 #include <gtk/gtk.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <X11/Xlib.h>
 #include <pthread.h>
@@ -40,10 +41,14 @@ typedef struct _ApplierClass ApplierClass;
 
 typedef struct _ApplierPrivate ApplierPrivate;
 
+typedef enum _ApplierType {
+	APPLIER_ROOT, APPLIER_PREVIEW
+} ApplierType;
+
 struct _Applier
 {
 	GtkObject         object;
-	ApplierPrivate   *private;
+	ApplierPrivate   *p;
 };
 
 struct _ApplierClass
@@ -51,14 +56,17 @@ struct _ApplierClass
 	GtkObjectClass klass;
 };
 
-guint        applier_get_type    (void);
+guint        applier_get_type             (void);
 
-GtkObject   *applier_new         (void);
-void         applier_destroy     (GtkObject *object);
+GtkObject   *applier_new                  (ApplierType        type);
 
-void         applier_apply_prefs (Applier *applier, const Preferences *prefs,
-				  gboolean do_root, gboolean do_preview);
+void         applier_apply_prefs          (Applier           *applier,
+					   const Preferences *prefs);
 
-GtkWidget   *applier_get_preview_widget (Applier *applier);
+gboolean     applier_render_color_p       (const Applier     *applier,
+					   const Preferences *prefs);
+
+GtkWidget   *applier_get_preview_widget   (Applier           *applier);
+GdkPixbuf   *applier_get_wallpaper_pixbuf (Applier           *applier);
 
 #endif /* __APPLIER_H */
