@@ -189,8 +189,8 @@ prefs_widget_destroy (PrefsWidget *prefs_widget)
 
 	g_free (prefs_widget->priv);
 
-	if (GTK_OBJECT_CLASS (prefs_widget_parent_class)->destroy)
-		(*GTK_OBJECT_CLASS (prefs_widget_parent_class)->destroy) (GTK_OBJECT (prefs_widget));
+	if (prefs_widget_parent_class != NULL && GTK_OBJECT_CLASS (prefs_widget_parent_class)->destroy != NULL)
+		GTK_OBJECT_CLASS (prefs_widget_parent_class)->destroy (GTK_OBJECT (prefs_widget));
 }
 
 static void
@@ -222,13 +222,15 @@ prefs_widget_init (PrefsWidget *prefs_widget)
 	spec = g_strdup_printf (skel, titles[0], titles[1], table_compute_state (SM_CHOOSE_FROM_LIST));
 	prefs_widget->priv->etm =
 		e_table_simple_new (model_col_count, model_row_count,
-				    model_value_at, model_set_value_at,
-				    model_is_cell_editable,
-				    model_duplicate_value, model_free_value,
-				    model_initialize_value,
-				    model_value_is_empty,
-				    model_value_to_string,
-				    prefs_widget);
+						NULL,
+						model_value_at, model_set_value_at,
+						model_is_cell_editable,
+						NULL, NULL,
+						model_duplicate_value, model_free_value,
+						model_initialize_value,
+						model_value_is_empty,
+						model_value_to_string,
+						prefs_widget);
 		
 	table = e_table_new (prefs_widget->priv->etm, NULL, spec, NULL);
 	prefs_widget->priv->table = table;
@@ -380,6 +382,8 @@ prefs_widget_class_init (PrefsWidgetClass *class)
 
 	class->state_changed = NULL;
 	object_class->destroy = prefs_widget_destroy;
+
+	prefs_widget_parent_class = gtk_type_class (gtk_vbox_get_type ());
 }
 
 GtkWidget *
